package jf.directory.models.services
{
    import jf.directory.models.CategoryModel;
    import jf.directory.models.SiteModel;
    import jf.directory.models.TagModel;
    import jf.directory.models.events.SiteModelEvent;
    import jf.directory.models.events.TagModelEvent;
    
    import mx.controls.Alert;
    import mx.rpc.events.FaultEvent;
    import mx.rpc.events.ResultEvent;
    
    public class RemoteDirectoryService extends RemoteService implements IDirectoryService
    {
        [Inject]
        public var categoryModel:CategoryModel;
        [Inject]
        public var tagModel:TagModel;
        [Inject]
        public var siteModel:SiteModel;
        
        public function RemoteDirectoryService()
        {
            super();

            remoteObject.getCategories.addEventListener(ResultEvent.RESULT, getCategories_resultHandler); 
            remoteObject.getTags.addEventListener(ResultEvent.RESULT, getTags_resultHandler); 
            remoteObject.getSites.addEventListener(ResultEvent.RESULT, getSites_resultHandler); 
            remoteObject.createSite.addEventListener(ResultEvent.RESULT, createSite_resultHandler); 
            remoteObject.createTag.addEventListener(ResultEvent.RESULT, createTag_resultHandler); 
            
            remoteObject.addEventListener(FaultEvent.FAULT, faultHandler);
        }
        
        public function getCategories():void
        {
            remoteObject.getCategories();
        }
        
        public function getTags( template:String ):void
        {
            remoteObject.getTags( template );
        }
        
        public function getSites( categoryId:int, tagsId:Array = null ):void
        {
            remoteObject.getSites( categoryId, tagsId ); 
        }
        
        public function createSite( name:String, url:String, description:String, categoryId:int, tagsId:Array = null ):void
        {
            remoteObject.createSite( name, url, description, categoryId, tagsId );
        }
        
        public function createTag( name:String ):void
        {
            remoteObject.createTag( name );
        }
        
        /*
        * Handlers
        */

        protected function getCategories_resultHandler(event:ResultEvent):void
        {
            categoryModel.updateCollection(event.result as Array);
        }
        
        protected function getTags_resultHandler(event:ResultEvent):void
        {
            tagModel.updateCollection(event.result as Array);
        }
        
        protected function getSites_resultHandler(event:ResultEvent):void
        {
            siteModel.updateCollection(event.result as Array);
        }
        
        protected function createSite_resultHandler(event:ResultEvent):void
        {
            dispatch(new SiteModelEvent(SiteModelEvent.SITE_CREATED));
        }
        
        protected function createTag_resultHandler(event:ResultEvent):void
        {
            dispatch(new TagModelEvent(TagModelEvent.TAG_CREATED));
        }
        
        protected function faultHandler(event:FaultEvent):void
        {
            trace(event.toString());
        }
    }
}