package jf.directory.views.mediators
{
    import jf.directory.controllers.events.LoadSiteEvent;
    import jf.directory.models.events.CategoryModelEvent;
    import jf.directory.models.events.SiteModelEvent;
    import jf.directory.views.components.DirectoryView;
    import jf.directory.views.events.TagSelectionEvent;
    
    import mx.collections.ArrayCollection;
    import mx.events.ListEvent;
    
    import org.robotlegs.mvcs.Mediator;
    
    public class DirectoryMediator extends Mediator
    {
        [Inject]
        public var view:DirectoryView;
        
        override public function onRegister():void
        {
            //view
            eventMap.mapListener(view.categoryTree, ListEvent.CHANGE, categoryTree_changeHandler);
            eventMap.mapListener(view.tagSelection, TagSelectionEvent.SELECT_TAG, tagSelection_changeHandler);
            eventMap.mapListener(view.tagSelection, TagSelectionEvent.UNSELECT_TAG, tagSelection_changeHandler);
            //eventDispatcher
            eventMap.mapListener(eventDispatcher, CategoryModelEvent.CATEGORY_HIERARCHICAL_COLLECTION , categoryHierarchicalCollectionHandler);
            eventMap.mapListener(eventDispatcher, SiteModelEvent.SITE_COLLECTION, siteCollectionHandler);
            eventMap.mapListener(eventDispatcher, SiteModelEvent.SITE_CREATED, siteCreatedHandler);
        }
        
        protected function validate():Boolean
        {
            return view.selectedCategoryId == 0 ? false : true;
        }
        
        protected function load(showHelp:Boolean = true):void
        {
            if(validate())
            {
                dispatch(new LoadSiteEvent(LoadSiteEvent.LOAD_SITE, view.selectedCategoryId, view.selectedTagsId));
            }
            else if(showHelp)
            {
                view.showHelp("Veuillez sélectionner une catégorie de l'annuaire pour lancer une recherche.");
            }
        }

        protected function categoryTree_changeHandler(event:ListEvent):void
        {
            load();
        }
        
        protected function tagSelection_changeHandler(event:TagSelectionEvent):void
        {
            load(event.type == TagSelectionEvent.SELECT_TAG ? true : false);
        }

        protected function categoryHierarchicalCollectionHandler(event:CategoryModelEvent):void
        {
            view.categoryProvider = new ArrayCollection(event.collection);
        }
        
        protected function siteCollectionHandler(event:SiteModelEvent):void
        {
            view.siteProvider = new ArrayCollection(event.collection);
        }
        
        protected function siteCreatedHandler(event:SiteModelEvent):void
        {
            load(false);
        }
    }
}